Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.

Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?

Register or sign in here: ucp.php?mode=register

Speak No Evil (2024)

Ghosts, Monsters, Vampires, Werewolves, and Witches oh my! Halloween/Horror Movie Collection.
(Satanic, Slasher, Splatter, Cannibal, Occult, Giallo, Chinese/German Underground/Japanese/Korean/New French Extremity Horror etc.)

Moderators: Maskath3, GabrielAlejo2341, sidolanters

Watch on Amazon   Horror Merch   Collectables

Horror, Scary, Halloween Movie Collection.

Speak No Evil (2024)

Post by bunniefuu »

(grand orchestral fanfare

playing)





(crickets chirping)



(engine shuts off)

(seat belts clicking)

(car doors open)

(car doors close)

(birds chirping)

Mom, you said ten minutes.

No, I said when I've warmed up.

-Mom.

-Agnes, indoor voice.

We're not indoors.

Yes, but there are

other guests here.

(Louise sighs)

Hey.

Is this chair free?

Um, yeah, sure.

Oh. Super. Super.

(chair scraping loudly)

(breathes deeply)

-WAITRESS: Signore.

-Oh, thank you. Grazie.

That's for you, kid.

Get it down your neck.

-Thank you.

-Cheers, my dears. To us.

(laughs):

Oh, we're on our holiday now.

You want a beer?

It's a little early.

-But if you want one.

-Nah. (clears throat)

PADDY:

Come on. We are getting in it.

Please don't give Agnes

any apple juice before bed.

-S, signora.

-And you've got Hoppy?

-AGNES: Mm.

-LOUISE: You got my number?

-WOMAN: S.

-LOUISE: Okay.

-(kisses) Love you, sweetheart.

-AGNES: Love you.

LOUISE:

Okay. Bye.

-AGNES: Bye.

-WOMAN: Ciao.

I swear, that bunny.

We need to stage

an intervention.

(sighs)

And start World w*r Three?

Look, she's with a stranger

in a strange place,

-and he makes her feel safe.

-Yeah, well, she's 11.

(loudly over speakers):

If everybody wants you

Why isn't anybody...

Ben.

Can we agree not to sit next

to the Danish couple this eve?

If I have to hear

one more word about their

(imitates accent):

"cooking class."

(Danish accent): Today,

we made the ravioli con funghi.

You should come

to the class tomorrow,

because I believe

they're making the gnocchi.

-Mm.

-Oh, it's gonna be great.

And you will love Giorgio,

who teaches us.

He knows everything

about Italian food,

and he even invented some

variations of these courses.

You know,

there's 23 different...

BEN:

Geez. 46 euros for risotto?

-AGNES: Dad.

-What?

LOUISE:

Agnes, keep your voice down.

I can't, I can't find Hoppy.

Okay, honey.

Let's calm down, okay?

Did you leave him

in the car or...?

No. No, I think

I had him at the church.

All right, all right. Don't

worry. We'll find him, okay?

-All right?

-It's okay. Baby, it's okay.

Here, Daddy's gonna find him.

Come on, let's go sit down.

-Let's do some...

-Louise, come on.

Ben, I can't handle

another meltdown, okay?

Louise, I'm...

Come on. Let's sit down.

Let's do some breathing.

-(mutters): f*cking bunny.

-Okay. Breathe in.

-(Agnes inhales deeply)

-One, two, three.

Hold.

One...



(baby crying nearby)

Coniglio? No? C-Coniglio?

No.

Grazie. Grazie.

(sighs)

PADDY:

Whoops, sorry. Whoa! (laughs)

Oh. It's so bumpy.

Watch out, watch out,

watch out.



-(women chattering, laughing)

-(church bell tolling)

Ah!

Oh, Dad, look,

they found Hoppy.

-Great. -Oh, yeah, Ant, he

recognized him from the hotel.

Oh, this is my husband Ben.

Yeah, I-I think

I stole your lounger.

-Ah, yeah.

-(chuckles): Yeah.

I'm Patrick Field.

This is my wife Ciara.

-Hello. Hi.

-Hey.

And, uh, you must be Ant.

Oh, Ant has

some trouble communicating,

so he can be a bit insecure.

-Hi, Ant.

-That's fine.

-This is Agnes.

-And this is Hoppy.

He's my worry bunny.

He smells really nice.

-(chuckles): Oh. -Aw.

-BEN: Nice Vespa.

Yeah, isn't she? We got her

from Paulo on the front desk.

-Oh. -It's an absolute blast.

You should try.

-Oh, no.

-Can we? Please, Dad?

-Honey, honey, please.

-Oh, wh-what, you don't ride?

-I mean, I can take you.

-Yeah.

-Uh, do you have helmets?

-I-I promise,

I'll-I'll be

really, really safe.

-But legally...

-I won't call the fun police

if you don't.

Come on, please?

PADDY: Oh, it's hard

to say no, isn't it? (laughs)

Uh, okay.

-Okay, give me your...

-Yes. -Yay.

Uh, just hold on tight, okay?

-Yeah.

-(engine starts, revs)

-All right, you holding on?

-Yeah.

All right, we'll go

nice and slow, okay?

-LOUISE: Yes.

-See you guys in a sec.

-Hold on tight.

-See ya.

-Bye!

-PADDY: Here we go. Bye.

-She's doing all right.

-(Louise laughing)

She's a natural!

-(Agnes yelps)

-Ooh.

(car horn honks)

No, she'll be fine. (chuckles)

-(tires squealing)

-(Paddy shouting in Italian)

-(car horn honks)

-(Paddy whoops)

-(laughs)

-(Agnes whoops)

(Paddy whooping)

-(Agnes whoops)

-Whoa!

That was a bit crazy. Oh!

-(tires squeal)

-(whoops) Nailed it.

-AGNES: Yeah.

-(Paddy chuckles)

-That was so much fun.

-Yeah? -You did great.

-Say thank you to Mr. Field.

-Thank you.

-Oh, no. Paddy, please.

-Thank you, Paddy.

You got it. Anytime.

So, listen,

have you guys eaten lunch yet?

Uh, no, we, uh...

No? We were thinking

we were gonna hang out

with that really interesting

Danish couple.

-You know the ones? (laughs)

-Uh...

-I'm j-just messing around.

-LOUISE: Oh.

-(laughter)

-But, uh, seriously,

there is a really nice place

around the corner.

BEN:

So we make the decision

that we're gonna move to London.

Fly over, find an apartment,

you know, I'm hiring

great new people,

and then...

(imitates expl*si*n)

Global economy tanks.

I get a call from Chicago.

"Uh, Ben, about that UK office

we wanted you to set up."

Aw, man, that's got to be

a kick in the ba*ls.

Yeah. They gave me

a good severance.

Yeah? That's redundancy.

And, Louise, do you work?

I do. Yeah. (laughs)

Uh, I'm, uh, I'm in PR.

Or I-I was. I am--

I, um...

I don't have quite

the-the same network in London.

Yeah, we're still

finding our way.

But we've decided to stay

in London because we love it.

We're two hours from here

or Paris or Rome.

The West Country.

-I don't think we've made it

out there yet. -Uh-uh.

-What? Oh, my. (laughs)

-(gasps)

Right, that's it, then.

You have to come and visit.

Really, it's beautiful.

Yeah, that'd be great.

Yeah?

Yeah.

-Done.

-(laughter)

-Well, all right, then.

-So what do you got?

You got another job

lined up or...?

Well, I'm still processing.

Look, I remember,

before I quit my practice, I--

-What was I like?

-Uh, miserable.

I was miserable.

-You're a lawyer?

-No, doctor. -Oh.

But now,

do a little bit of work

-with Mdecins Sans Frontires,

and I'm... -He is...

-Oh, wow. -Wow.

-CIARA: He is so much happier.

PADDY:

I'm so much happier.

Anyway, this tagliata

is delicious.

How's your polenta?

Looks a bit dry.

No, it's fine.

So you're a vegetarian?

For animal welfare

or personal health?

Yeah, for-for health benefits

and the animal welfare

and the environment.

No, no, no.

You don't have to go on.

It's-it's the future.

Mom, can we go play

on the swing?

-Uh, yeah.

-Don't you want a dessert?

No, no, she's already had

her ice cream for the day.

-Oh, wow, you guys are tough.

-(chuckles)

Ant, you can play, but stay

where we can see you, okay?

And don't disturb anyone, okay?

Oh, that's all right.

The Italians love children.

Not like the French.

CIARA: It's so great for Ant

to find a friend to play with.

At the hotel,

the other families' kids,

they all seem

to know each other.

And, well, Ant struggles.

-Um...

-Could I?

He, um, he has a condition.

Congenital aglossia.

Um, laymen's terms,

he was born with a much smaller

tongue than you or I.

-Makes it hard for him

to communicate. -Ah. -Mm.

But look, these two,

they're getting on great g*ns.

Shame they can't stay

this age forever.

Oh, sh*t.

-The Danes.

-PADDY (laughs): Oh, no.

BEN (chuckles):

Hey.

PADDY: He's seen us.

He's totally seen us.

Oy. Go with me on this.

Torsten.

-Yeah. Hi.

-Hey.

-Hey, have you guys eaten?

-No, we haven't.

Do you want to come join us?

Actually, we could use

your help with a, uh,

-quite important debate.

-Yeah.

(clears throat) Sorry.

This food is so rich.

We're debating

toilet paper protocols.

So, uh, to scrunch or to fold.

What do you do?

Uh...

I don't know.

Oh, all right.

Well, Louise is fold,

Ciara is scrunch,

but, you see, Ben and I,

we worry that if you fold,

you risk a puncture and you get

a bit of poo on your finger.

So, what should we do,

get another three chairs?

No, no, we were

actually just looking

to make a reservation

for later, so...

Oh, all right, man. Um, okay.

Well, see you guys

back at the ranch.

Yeah.

-Bye, then. (mutters)

-Cheers.

-(laughter)

-What?

Paddy, you're terrible.

-Terrible. -You do not know

the half of it.

(laughter continues)

(lively chatter)

A hundred percent, sure.

Was it last year or

the year before we went there?

Oh, yeah.

Oh, Torsten, you haven't said.

Fold or scrunch?

-(laughter)

-Oh, man.

I know. I'm really sor--

I'm really sorry.

Anyway, sorry, mate.

Here we go.

GROUP:

Tre, due, uno.

(cheering)

(laughter)

-PADDY: To new friends.

-(glasses clink)

OTHERS:

To new friends.

(siren wailing in distance)

LOUISE:

(shrieks) Oh, God.

Remind me why we live

in London again.

Come on. Go inside. Let's go.

(Louise groans)

(sighs)

All right.

Good night, honey.

And Hoppy.

Hon, you remember our agreement?

Hoppy gets his own room

before Christmas.

Right?

You're almost 12 years old.

Love you.

I love you, too.

(door opens, closes)

I don't think Hoppy's getting

his own room before Christmas.

I mean, Louise,

do you think we should worry

-about why the...

-Ben, would you...

She'll hear you.

It's probably better

that she does.

Are you okay?

I got a call from

the headhunter today.

I didn't get it.

Oh.

Honey, I'm sorry.

(phone chimes, vibrates)

(Louise sighs)

-It's Penny.

-Mm.

Agnes's math tutor.

You want to read it?

No.

-(sighs): g*dd*mn.

-(sets phone down)

Uh, look who wrote us.

Your friend.

"Ciao, Ben and Louise.

"We so miss our amazing week

together in Italy.

"You really must come visit

the farm. What do you say?

"A long weekend of Devon air,

fresh food and long walks.

"Ant sends Agnes good vibes.

-He really misses her."

-(chuckles)

Very sweet.

Hey.

Maybe this will be good for her.

Uh, for us.

You know, change of scenery.

Yeah.

It's maybe a bit long to spend

with people we barely know.

Yeah.

You're probably right.

(sighs) Anyways.

-(sighs)

-You know what?

I think we should go.

-Yeah?

-Yeah. Be fun.

Yeah?

Oh, gosh.

Look at that.

Yeah. Look at that.

(tires rolling on gravel)

BEN: Are you sure

we didn't miss the turn or...

Well, I don't know. We haven't

seen the-the w*r memorial yet.

-(sighs heavily)

-Ben, please don't get angry.

I'm not angry.

C-Can you call them

or-or ask or...

There's still no... (sighs)

Oh.

Oh. w*r memorial!

Left. Left, left, left.

(night bird calling)

-Baby.

-AGNES: Hmm?

We're here.

(Ben sighs)

Get me out of this car.

(Ben sighs heavily)

-Hey! -Hey!

-Hey!

-You made it.

-Hi.

PADDY:

We thought you were lost.

-Oh, no. -Ah. Well,

we thought we were lost.

-No, we didn't.

-Oh, yeah?

Good to see you, darling.

-Come on. We'll get you in.

-BEN: This place is just so...

Oh, wow. Oh, sorry, shoes.

Oh, no, you can leave them on.

Don't worry.

-Sorry for the mess. (laughs)

-Oh, no.

-Shall we put your bag

in your room? -Yeah.

-Wow.

-You like it?

-Wow, this place.

-(laughs)

Innit? Let me get you a drink.

Ooh.

-Very steep.

-Here we go.

(gasps) Wow.

Cozy. (chuckles)

PADDY:

Cider.

From our very own farm apples.

-No.

-Yeah.

(chuckling)

That's the good stuff, right?

-Strong.

-(laughs)

Just you wait till

you try our calvados.

-It's 150 proof.

-(bottles clink)

CIARA:

Ant?

It's Agnes.

Oh. Say hi to Ant, sweetie.

Hi, Ant.

Oh, he's just a little shy.

Look, Agnes,

we made you a little bed.

Do you like it?

Yes.

It's great.

Ant, it's time for dinner.

-Come down when you're ready.

-Yeah.

LOUISE:

Oh, and we got you this.

CIARA: Oh, a candle.

You shouldn't have.

LOUISE:

This is, uh, Feu de Bois.

It's the scent

of a log fireplace.

That's good. We can stick it

next to the log fireplace.

(laughter)

BEN: And for the football fan.

Hut, hut!

Ah, Ben, Ben,

you shouldn't have, man.

-That's really-- Ant.

-Ah, please.

Ant, what do we say?

That's my boy. Hut!

I'm coming for you, boy.

I'm trying to get him to play

more contact sports, you know?

It's good... (laughs)

It's good... (kisses)

-It's good for them, you know?

They need that outlet. -Yeah.

God, I used to love

a tear-up, man.

What about you?

Do you play ball?

-BEN: Yeah, I mean, a little.

-Oh, yeah? Hut.

-Wh-Whoa, whoa.

-(laughs)

PADDY: My reactions ain't

what they used to be either.

All right.

Rosse Arance di Sicilia.

It's Italian blood oranges.

-But look at the color in the...

-Mm-hmm. -Ooh.

LOUISE:

Wow.

You are VIP guests.

When Paddy heard

you were coming,

he butchered Libby,

our prize goose,

and has been hanging her

in the outhouse.

PADDY: She was some bird,

Libby. Regal girl.

Real queen of the farmyard,

you know?

I mean, what was she like?

-She had personality.

-She had personality.

(Paddy and Ciara laugh)

PADDY (singsongy):

Ta-da!

-Libby l'orange.

-(Ciara and Paddy laugh)

PADDY: All right.

The old man's carving forks.

Sous chef, if you please.

-Just to...

-Raised with love.

Free-range.

Our wheat,

our grass, our orchards.

And now, Louise, my love.

Our gift to you.

(chuckles):

Oh, God, that is so...

It-It's just a tiny morsel.

-Um, I'll try it.

-(Paddy stammers)

Well, we thought, for the lady.

It's the best part of the roast.

Really crispy and yet

somehow manages to be soft

-all at the same time.

-Mm.

(chuckles)

Mmm. Mmm.

-PADDY: It's good, right?

-LOUISE: Mm-hmm.

-It's okay? -Mmm. Very good.

-(laughing)

(Paddy and Ciara laughing)

BEN: Can I, uh, can I help out

with anything?

PADDY: Oh, what a gent.

Uh, yeah, that would be great.

Uh, serving platters,

second shelf.

Oh, they're just round there.

-Ah.

-Thank you. (chuckles)

(Ant babbling)

(Ant coughing softly)

(babbling)

-(hands clapping)

-PADDY: Ant, come on, mate.

Bedtime. Chop-chop.

That's my boy. (chuckles)

-Kids, right?

-Yeah.

-(Paddy sighs)

-Geez.

Are those original to the house?

Yeah. Keeps the heat in,

keeps the highwaymen out.

Geez, it's so quiet around here.

I mean, do you guys

even have any neighbors?

Yeah, all the way

across the valley,

but, you know,

we look after each other.

BEN:

Ours are across the hall,

(chuckles): and I don't think

we've ever spoken.

Louise, you have a bad neck?

No, uh, it's just something

that flares up sometimes.

PADDY:

Medicinal? It's homegrown.

No, thank you. I took a pill.

Oh, modern medicine.

It is amazing.

But too often

we treat the symptom.

We don't treat the cause.

You know, technology's

advanced incredibly,

but emotionally speaking,

we're all still just...

(inhales sharply)

cave dwellers.

It's all this perfect life,

Instagram, Facebook bullshit.

Everybody talking

but nobody being honest.

It's left us--

I don't know--

impatient and stressy.

CIARA: The Internet's been down

a half a day,

and I've nearly

bloody k*lled him, so...

-(laughter)

-(Ant wailing upstairs)

BEN:

I love it out here.

It's like a digital detox.

You know, get away from London

for a while.

-(Ant continues wailing)

-PADDY: Yeah.

Is he, is he all right?

Oh, no, no, he's fine.

-Yeah.

-Um, he'll crash in a minute.

He does this sometimes.

It's just part of his condition.

He's not in pain?

-No. -PADDY: Uh, no.

-Okay.

No, no, no. No pain.

-You know, I'm gonna just check

on Agnes. -Yeah. Yeah.

Wait. No, no, no, no, no.

(grunts)

(Ant continues wailing)

(wailing stops)

-(fingers snap)

-He's conked.

Wow. (chuckles softly)

(shuddering groan)

BEN: You should've

said something to him.

They k*lled Libby,

the golden goose.

I was trying to make an effort.

I know. I know.

Oh.

-Ew.

-What?

Ben.

Do you think

these have been washed?

Oh, I think

we should say something.

No, honey, that is an old stain.

Look, we're in the country,

all right?

-Our normal isn't their normal.

-(sighs heavily)

They're just a bit more--

I don't know-- unvarnished.

You don't think

it's weird for a doctor

to live in a house like this?

Look, this isn't America,

all right?

He does nonprofit work.

And they probably choose

to spend their money

on less material things,

you know?

Like vacation.

(sighs) Mm-mm.

Do you have any idea what

the inside of Downton Abbey

actually looks like?

It's a sh*thole.

(laughing softly)

Hey.

Thank you for making the effort.

(Louise sighs softly)

-You're welcome.

-(door opens)

Hello? Oh.

(chuckles):

Hi, baby.

I can't fall back asleep.

-Oh, honey. That's all right.

-That's okay. Come on.

Let me get your breathing app

going for you.

No, no, no, I have it here.

Come on. Come in bed, baby.

Come on, come with Mom.

-AGNES: Can we

keep the light on? -No.

LOUISE:

No, honey.

Here we go.

-Okay.

-(Agnes breathing deeply)

BEN:

We just need to calm down.

Settle in.

I promise you guys,

it's gonna be a great weekend.

(deep breathing continues)

PADDY:

Awake, awake

-Sweet England

-(Ciara chuckles)

PADDY and CIARA:

Sweet England now awake

And to the land obediently

And let us all partake

Have a look in there.

What's that?

For our future now

is calling...

That's called "gills."

("Awake, Awake Sweet England"

by Sam Lee playing)

All in the skies so clear

So resound...

Oh, be careful.

That's really sharp.

-It's firethorn.

-Oh.

Don't want you getting hurt,

do we? (chuckles)

PADDY: So you just

got to start slowly.

It has to warm up.

(blowing)

Hard.

And to this living story,

let us sing.

(cheering)

(song ends)

PADDY:

Wait, wait, see? You see?

-LOUISE: Mm.

-BEN: Ooh.

Cheeky b*stard.

-You should have brought

your r*fle, hmm? -Yeah.

-(laughs): I'm glad you didn't.

-(Paddy chuckles)

An American

who doesn't like g*ns?

Oh, well,

I saw my share growing up.

If unchecked, foxes, they k*ll

all the ground-nesting birds.

Predator control is essential

to a balanced ecosystem.

-Balanced ecosystem.

-It is. -LOUISE: Mm.

(chuckles) Yes, I'm sure

a factory-made firearm is

nature's way of keeping that

delicate balance. (chuckles)

Mm.

-AGNES: Mom?

-Ah. Excuse me.

(inhales deeply) Look at this.

You... Ant?

Do you think

you could move, honey,

so that Agnes can have a swing?

Uh, oh, hello.

Um, do you mind asking Ant

if he'll move?

-Just so that-- Agnes wants

to have a go. -Come on, pal.

-Just for a second.

-(snorting playfully)

Give you a piggyback, yeah?

Come on. (snorts)

Go on.

I'd have felt the back

of my dad's hand by now.

Paddy, Paddy. I-It's okay.

You don't, you don't have to.

It's all right, it's all right.

You want to, don't you, mate?

Go on. Give Agnes a push.

Good boy.

(spits)

(laughs): Oh, come on,

that is not a push.

There. That's my boy.

-You flaring up?

-Yeah, it's just a...

-May I?

-Oh.

Go on, loosen your knees.

Oh, wow.

Yeah.

Your levator scapulae

is like a rope.

(Louise groans)

-Can we just...

-(neck cracks softly)

Yeah. (sighs)

(Louise chuckles nervously)

I know what you need.

Cold water therapy.

Clinically proven to reduce

inflammation and? Anyone?

Boost the immune system.

-LOUISE: Oh.

-Yeah.

W-Well, we didn't bring

our swimsuits.

Oh, that's all right.

You can keep you knickers on.

Oh, what happened?

(chuckles):

Oh, um...

Oh, uh, it got a little bit out

of hand last night. (chuckles)

(chuckles): I fell off

a ladder, picking apples.

PADDY:

Come on, you lot.

Get your kit off.

I promise we'll whack up the

heating in the car afterwards

and we will be warm again

in no time.

You shouldn't be shy, Louise.

Got a great body.

Oh, thank you.

Yeah.

Right. Make sure when

you jump out, clear the rocks.

All right. Ant, Agnes,

jump with the dads, yeah?

-Ready? In three, two...

-LOUISE: Oh, hold on.

One-one second. Sorry, sorry.

Uh, uh... (stammers)

-Is it safe? Is it deep enough?

-Uh, yeah.

I've done it hundreds of times,

since I was her age.

Yeah, just mind

you clear the rocks.

All right,

in three, two, one, go!

(all yell)

(Louise laughs)

-Oh! Whoo!

-(Ant coughing, gasping)

Go on, boy!

-Paddy, can he swim?

-Yeah, yeah, yeah.

Same way I learned:

sink or swim.

He'll be fine. Go on, Ant.

Oh, my God,

can Ant... can Ant swim?

Oh, don't worry.

Paddy's got him.

Shall we?

Oh, um... uh, y-you go ahead.

Okay.

(whoops)

-CIARA: Come on, Louise!

-PADDY: Go, Louise!

-Come on!

-(whooping)

-Come on, jump, jump, jump!

-Come on, jump!

(chanting): Jump! Jump!

Jump! Jump! Jump! Jump!

Jump! Jump! Jump!

-(Ciara whoops, laughs)

-(Paddy grunting playfully)

-(hair dryer whirs, pops)

-(Louise shrieks)

-(gasps) Oh, God.

-Geez!

That's a f*cking fire hazard.

(Louise panting)

Look, Louise,

do you want to take a nap?

(laughs)

Yeah, in their dirty bed?

Okay, let's everybody just...

I'm sorry.

I am trying.

I really, really am.

I just...

I don't find them

that pleasant to be around.

BEN:

Okay.

Maybe we could use my neck

as an excuse.

-To leave?

-(knock on door)

-Hey.

-LOUISE: Hi.

Am I interrupting?

N-No.

Well, Paddy and I would like to

invite you for dinner tonight.

-Ooh.

-Yeah, there's this guy Mike.

He's a bit of a local legend.

I mean, rumor is he's a poacher,

but he's an amazing cook.

(chuckles)

And, um, he has

this little place by the sea.

Private room,

like a chef's table type thing.

-Oh, wow.

-Mmm.

Yeah, and it's super authentic,

everything fresh, local.

(chuckles)

-Um... great.

-Great.

-BEN: We-We'd love to.

-Great.

She seems really unpleasant.

Okay, I was j--

Hey, let's...

let's try and reboot.

All right?

Remember what Nadine said?

Let's not make the perfect

the enemy of the good.

(Louise groans softly)

(kisses)

AGNES: Oh, I hope

they have French fries.

Well, I'm sure

they will have chips,

because that's

what they're called here.

-(Ciara laughs)

-Oh, wow! (laughs)

You look like a million bucks.

-Thank you. You look lovely.

-(Louise laughs)

PADDY:

You know what they say, man.

Happy wife, happy life.

We don't actually shop

that often.

I mean, our philosophy...

Spend wisely

on the things that last.

Yeah, that last, like, uh,

a watch or a ring or a memory.

-(laughs)

-Like Italy.

CIARA: Yeah, and everything's

so disposable now,

so "fast fashion."

Isn't Ant coming?

Hey, Muhj! There he is.

So, Muhjid doesn't speak

the best English,

-but he's a great babysitter.

-Hello.

LOUISE:

You're-- Oh.

Oh, the-- are the kids

not coming with us?

CIARA: Oh, no,

tonight's without the kids.

Didn't I tell you that?

PADDY: Muhj had to flee

the w*r in Syria.

His hometown, Homs,

just obliterated.

LOUISE:

Oh.

God, I'm so sorry.

Oh, thank you, sir.

PADDY: Poor bugger, he's stuck

in the asylum system.

Can't officially work.

CIARA: Don't worry.

He's thoroughly trustworthy.

-Back home, he was a teacher.

-Oh.

CIARA:

He's great with kids.

The whole neighborhood

feels the same.

And not just 'cause he's cheap.

(laughs)

(laughs)

Yeah, and the best part is

if there's any monkey business,

we'll get him deported.

(Paddy and Ciara laugh)

-Brother, have a great night.

-Come.

Come with me.

Let me show you. Come.

LOUISE: So do you think

we should leave her with him?

BEN: We've had nannies before,

and he was a teacher.

Come on, Louise.

Let's go have a good time.

-(chuckles) Okay. Bye, baby.

-PADDY: Hey, guys! Coming?

Come. Come, come.

("Animal" by Def Leppard

playing loudly over stereo)

-And I need

-(tires squeal)

And I lust

Animal...

(stammers) Hey, Paddy.

-Are we almost there?

-Very soon.

(tires squeal)

(Louise chuckles nervously)

(song ends)

BEN:

Wow. Wow, this place.

Oh, my God.

Yep, America's that way.

Dinner's that way.

The good news is,

we're the only diners tonight.

Oh, it's so cute.

Yep.

Not gonna find this on Yelp.

Mike goes out at night on

his own, sources all the food.

Incredible chef. He's...

(laughs)

You should taste his game pie.

-It's like... (gobbling)

-(Ciara laughs)

PADDY:

Amazing.

Um, but just to remember,

I'm a vegetarian.

-Wait, yesterday.

-I know.

I'm... (laughs nervously)

I should have said something.

I just-- I-- (stammers)

You guys had gone

to so much trouble...

-CIARA: Oh, it's...

-Oh, mate, mate.

I feel like such an idiot.

I'm so sorry.

BEN:

It was okay. Uh...

-Yeah, it was okay. (chuckles)

-PADDY: Okay?

Really, don't worry about it.

Great. But you do still

eat fish, yeah?

-Yes. -Great. But--

Fish is not a meat?

(chuckles) Of course.

But, you know, it's better

for the environment.

Yeah, but the way

that industrial fishing

treats the oceans.

That is why I fundraise

for sustainable fishing

and for ecolabeling

on packaging...

That kind of pescatarianism

is a privilege.

LOUISE: Absolutely, but that's

not a reason not to do it.

PADDY: What if you can't afford

line-caught?

LOUISE: Well, surely

you're not advocating

we all eat factory meat.

Rather than, you know, Libby.

(chuckles)

It's... complicated.

Can we agree?

It is. It's complicated.

It is really complicated.

And complicated is good.

Too many people these days

are afraid of honest debate.

Aren't they?

We're all too f*cking polite.

-Hey. Look at this sucker.

-There you go, eh? -Whoa.

Now, we trust that this is

sustainably sourced seafood,

Mike.

MIKE: Yeah, well, it's, uh,

it's done with Devon butter,

uh, wild samphire,

forest-foraged mushrooms,

cooked in, uh,

sustainable Devon cream, eh?

-Fantastic.

-Yeah.

Uh, not the poisonous ones,

right? We can trust you, Mike?

Oh, well, that would be

telling, wouldn't it?

(Paddy and Mike laughing)

Right. Pot time. (chuckles)

(Paddy and Ciara laughing)

MUHJID (in distance):

...24, 25...

(Ant sighs)

MUHJID:

...26...

(whispering):

Under the bed.

MUHJID:

...27, 28...

-MUHJID: ...29...

-AGNES: Whoa.

-That's a lot of watches.

-MUHJID: ...30.

(singsongy):

Ready or not, here I come.

I don't understand.

(singsongy):

Hello.

Where are you, little creatures?

(Ant's breath trembling)

LOUISE: You know,

they say, you either become

-like your parents or you go

the opposite way, right? -Mm.

I never met mine. (chuckles)

PADDY:

Hey, that's their loss, baby.

-Their loss.

-(chuckles)

Mine were, if you'll excuse

the French, a couple of c**ts.

So, you went

the other way or...?

(Ciara and Paddy laughing)

"They f*ck you up,

your mum and dad.

"They may not mean to,

but they do.

"They fill you

with the faults they had

"Then add some extra

just for you.

"But they were f*cked up

in their turn

"By fools

in old-style hats and coats,

"That half the time

were soppy-stern

"And half

at one another's throats.

"Man hands on misery to man.

"It deepens like

a coastal shelf.

"Get out as early as you can,

And don't have

any kids yourself."

-CIARA (whispers): Hey.

-(Paddy chuckles softly)

Baby.

(sobs):

She f*cking...

She rescued me, this one.

Saved me from the pit.

-Straightened me out.

-(Ciara chuckles)

And it's been what now?

17 years.

-PADDY: 17 years. -Wow.

-(Ciara laughs)

You get less for m*rder.

(laughing)

And, you know, we still...

you know, every day.

-Every day? Oh, my God.

-(Ciara chuckles)

LOUISE: f*ck. Ben's lucky

if he gets it once a month.

-PADDY: What?

-CIARA: Oh.

Well, you've got to work

at it. (chuckles)

I know.

CIARA:

I mean, sometimes we role-play.

-(chuckles) -Yeah.

-LOUISE: No.

-Seriously.

-Yeah.

Teacher and student.

LOUISE:

Mm.

Rock star and fan. (chuckles)

Strangers at a bar.

Horny waitress and hot customer.

Oh, my God.

-CIARA: Sir?

-PADDY: Mm-hmm?

CIARA:

How was your food?

PADDY: It was tasty,

but I do like more spice.

-CIARA: Do you?

-PADDY: Yeah.

(laughs):

Stop it.

Well, maybe for dessert, we can

go for something off menu.

Yes, please.

Oh, no.

Oh, sir, I think

you've dropped your napkin.

-I did. f*ck.

-I'll just slip under the table

and sort that out for you.

(Louise laughs)

(chuckles):

Okay.

-(Paddy grunts)

-(Louise chuckles)

(Paddy grunts, moans)

-(Paddy grunts)

-(thumping)

(Ciara laughs)

(laughing):

We were not really.

(Ciara and Paddy laughing)

Oh, I love this woman.

Love her.

What is the biggest

sexual organ in the body?

Mm?

The brain.

What we can imagine is

infinitely more sexy

-than what we can do.

-Mm-hmm.

Just-just keeps it fresh.

Which is why we both like

to dine out sometimes.

Yeah. Yeah.

-(Ciara chuckles)

-PADDY: Yeah.

Oh.

We think it's healthy. Mm.

-("Black Velvet" by Alannah

Myles playing) -Mm. Okay.

-(chuckles)

-Oh, my God. I love this tune.

Mike, bang it up, will you?

-(Ciara laughs)

-My dear?

(song continues louder)

So, she was how old

when they met?

-Louise, don't go there.

-(chuckles)

Mississippi in the middle

of a dry spell...

-(laughs) That is punchy.

-Um, Paddy... -(shushes)

-Worth every penny, Mike.

-Paddy. We'll pitch in.

Oh, that's very kind of you,

man. We'll get the car, okay?

CIARA:

Thank you, kind sir. (chuckles)

(door closes)

(muffled grunt)

(breath trembling)

Ant, what are you doing?

God. Ant, what did you do?

How did you get those?

(footsteps in hallway)

(door opens)

CIARA (hushed):

Oh, she's an angel.

(door closes)

(whistling a tune)

(whistling stops)

(door opens)

(door closes)

New book?

Yeah. Um, Paddy recommended it.

Wow, you guys should

go off together.

What?

Or I could just switch rooms

if you like.

Louise, what the f*ck

is wrong with you?

-What?

-Why would you say that

after everything

that we've been through?

Hey, I was joking.

Yeah, no, but you do it

all the time.

You know, b-belittling me.

I mean, saying that

I'm lucky to get laid?

Ben, that was a joke.

Yeah, but it's not

f*cking funny.

Not when you're sexting a dad

at your daughter's school

-like a f*cking teenager.

-Okay. Okay. Ben.

-Ben, please.

-Well, think about it.

-How does that make me feel

when you say that? -I know.

I know, and I have said that

I am sorry a thousand times.

But I-I don't know

what to do anymore.

I mean, it's been six months.

-We've been over this with

Nadine a thousand times. -Yeah.

Yeah, that it's my fault.

-No, no, no, no.

-And Aggie...

I take responsibility

for my actions.

-But you... you are so angry.

-Yes!

-For seeing another man's d*ck

on my wife's phone? -(shushes)

Please. Listen.

I am not excusing that,

but you were angry

long before that, okay?

You are so bitter at the world

for not giving you

what you think you deserve

that-that you don't

-see all the things

in front of you. -(stammers)

You can't turn this all on me.

I moved to London for you.

I upended my life.

I lost my job. I lost my house.

I lost everything

that makes me me, for you.

And when you lost your job,

I agreed to stay

and help you and support you

and keep your life

running smoothly

so that you could have access

to all of Europe.

But where the f*ck is

my access to my husband?

You know, I-I don't know

if you're with me

because you love me or because

you just can't stand to fail.

(softly):

Look.

Louise, I'm...

I do care.

I'm...

I'm really trying.

(sighs heavily)

(clicks tongue) Yes.

We both are.

(sighs)

Let's...

please...

be friends.

(Ben sighs)

Look, I'm sorry.

I'm sorry.

(door creaking)

(floorboards creaking softly)

(door creaking)

(whispers):

Agnes, baby.

Ben.

Ben.

What?

-We're leaving.

-What?

(car doors close)

(Agnes breathing heavily)

Mom? Where's Hoppy?

Uh, I-I don't know.

Did you have him when we left?

I don't think so.

(bag unzips)

(Ben grunts)

LOUISE:

Sweetie, he's not there.

AGNES:

I want Hoppy.

Agnes, you got to grow

out of this.

You're almost 12 years old.

Ben, it's not helpful. Please.

Listen, when we get home, we'll

ask them to mail him, okay?

He'll get hurt like Ant.

Honey, Ant's not hurt.

He was born like that.

-We'll buy another Hoppy.

-No, I need my Hoppy!

Agnes, please calm down, okay?

-They're gonna do that to Hoppy!

-Breathe. Agnes!

-(grunts angrily)

-Hey! Enough!

-Hey!

-(truck horn blaring)

(yelps) Oh, my God!

(panting) Oh, Jesus.

Oh. You okay? Are you okay?

We can't leave him there.

We can't leave him there.

They're gonna do that to Hoppy.

I can't breathe.

I can't breathe.

(Agnes breathing heavily)

(birds chirping)

All right. I'll be right back.

What if they're awake?

Louise, just give me

two minutes, okay?

(sighs)

(Louise sighs)

Okay.

-Be right back, okay? Okay?

-(seat belt clicks)

(gate creaks)

-PADDY: (grunts) No. No.

-Louise, um,

j-just go back to the car.

-I'll be there in two minutes.

-(sighs)

Look, like I said, we didn't

want to, like, wake you...

-What?

-What's going on?

Uh, we've got

a bit of a situation.

Someone was leaving

without saying goodbye.

No, look, I was just saying to

Paddy we had such a good time.

Well, then I've got to ask

again, wait, why did you leave?

-Be honest.

-(Ben stammers)

Look, look,

some-some things happened

that made us feel like it was

best that we head back home.

What things?

Uh, I think we deserve to know.

CIARA:

Mm-hmm.

A-Agnes doesn't like

sleeping on the floor,

and so she-she comes

into the room at night

and the-the bed's

really small, so we...

-I'm sorry that our house

isn't huge... -No, it's not...

CIARA: ...and that

Agnes doesn't feel comfortable

-in Ant's room, but...

-No!

She was in your bed.

-PADDY: What?

-Yeah.

-Who? What?

-Our daughter was in your bed.

-Yes, I'm sorry. Okay?

-Ciara?

Paddy was asleep

for the whole thing.

That's my fault, okay?

Well, I'm-I'm sorry,

but-but that is crossing a line.

-I mean, th-that is not okay.

-Uh, it's my fault. I'm sorry.

I'm-I'm sorry.

I... Look, I know I can be

overprotective as a mother.

Wh-What does that

have to do with it?

(chuckles)

We had a baby daughter.

Uh, no.

Mary.

And, um, she died

at 12 weeks of a cot death.

We would've been

the perfect family.

So hearing Agnes crying,

it just... (sobs softly)

Um, so, she was just--

she-she was--

She kept calling for you,

and-and you didn't come,

and she was beside herself,

scratching herself and...

Well, and you weren't

there, so...

Look, you-you know how hard

it is trying to decide

when to intervene

and when to give them space,

and I'm... I'm so sorry

if I got it wrong.

I'm so sorry.

(breath trembling)

-Ciara. I didn't know.

-Like, we are...

Mom! Ant found him!

-Oh, good. (sighs)

-Oh.

PADDY:

Good boy. Good boy.

-(Ant clucking)

-(Ciara and Paddy chuckling)

-What's he saying? -PADDY:

I think he's trying to say

he's sad

you're leaving because...

'cause he wanted to show you

the chickens.

(Paddy chuckles)

-Can we?

-Uh...

Hey, you remember that time,

the first time you came to stay

and you tried to leave 'cause

you flipped out in the night

-and you didn't say goodbye?

-(chuckles)

Eh? (laughing)

-(birds chirping)

-(chickens clucking)

They look sweet together,

don't they?

We wanted another.

But...

after two miscarriages...

CIARA: Life can be

so f*cking unfair. Sorry.

I don't understand.

Ant, I can't read it.

(stammering)

-How are your eggs

coming along? -Good.

Let's see.

LOUISE:

Oh, these are great.

CIARA:

I think, Agnes,

that yours is the best.

(chuckles)

(Louise chuckles)

LOUISE:

Oh.

("Eternal Flame" by The Bangles

playing over speakers)

(Paddy singing along quietly):

Close your eyes

Give me your hand, darling

Do you feel

my heart beating?

Do you understand?

Do you feel the same?

Am I only dreaming?

Is this burning

An eternal flame?

But it made no sense.

It was gobbledygook.

Can I see it?

He ate it.

LOUISE: I think

he's going through a lot,

and we need to be kind.

-Okay? -No, something's

not right with him.

(chuckles):

Okay, Agnes,

sometimes it's okay

to think things,

but you can't actually say them.

Mom, it's not normal.

CIARA:

Agnes, love,

do you want to

come help me peel these?

(Louise chuckles softly)

Some nice carrots, hmm?

Sorry, man.

Oh.

No, here, give me that.

Here we go. (sniffs)

(sighs)

It's not even about

the k*ll for me.

It's always been about the hunt.

You know?

Getting them in the crosshairs.

Luring the fish onto the hook.

That's the game.

That's what I live for.

Look, maybe this isn't my place,

but last night,

we heard you two shouting.

I'm sorry, man.

You know, cheating is

really hard to get over.

(sighs heavily)

Louise didn't actually.

It was... it was just text.

Mm. Whatever she did,

thoughtcrime or whatever,

just-- who cares?

All this...

all this in here...

That's gonna eat you alive.

You got to let it out.

Will you let me

show you something?

(Paddy panting heavily)

(yelling wildly)

(Paddy breathing heavily)

(yelling wildly)

(both yelling wildly)

(both gasping for breath)

(yelling wildly)

(yelling wildly)

(both yelling wildly)

(both breathing heavily,

laughing)

-PADDY: I'm starving!

-(Ciara laughs)

-And you do it four times.

-PADDY: Could eat a horse!

And then-- Do you want me

to show you the first part?

Could eat a Ciara. (chuckles)

So it's like that. One, two...

Oy, oy, come on.

Careful, kids. All right?

You knock over one of

your mother's sculptures

-and there will be hell to pay.

-(Ciara chuckles)

-Have you shown them these?

-No.

Guys, have you seen this?

This is Ciara's.

One of many.

It's called Mother's Love.

-BEN: Wow.

-LOUISE: Oh.

-Yeah? Yeah, one of many.

-Oh, God.

-Ciara, those are stunning.

-Wow.

-I mean, it's just a hobby.

-Hey, don't put yourself down.

That's my job.

Louise, thank you so much

-for helping with the cooking.

-Yeah. Of course. -Paddy.

Mom. Mom. Can Ant and I

show you our dance?

-LOUISE: Ye-- -CIARA: Oh.

Maybe after lunch, sweetie.

Actually, Agnes, could you set

the table for me, please?

Oh, yeah. Go on, Agnes.

Show Ciara how good you are

at setting the table.

(pained yelp, inhales sharply)

-Ooh. -Oh, God.

-What happened?

-Honey, honey, run it

under the tap. -Mm, mm, mm.

-You okay? -You all right?

-Mm-hmm, mm-hmm.

Hey, um, uh, Paddy, can you

come take a look at this?

-(Louise shuddering)

-Uh, yeah, sure.

Thank God there's a doctor

in the house.

I'm not a doctor.

-What?

-Wait.

Well, didn't you say

you were a doctor?

Did I?

BEN:

In-in Italy, you...

(sighs) Look.

Uh, sometimes

when I meet new people, I...

I'll get a little bit

self-conscious, you know?

-He just wants to make

a good impression. -Yeah.

What do you,

what do you do, then?

Well, I don't do anything.

BEN:

Like, anything?

No. Well, I don't work.

I don't believe in it.

-LOUISE: Oh.

-Yeah, we get by, right?

-Mm. Mm. -Yeah, we sell

a bit of marijuana,

drop a bit of cider

to the locals.

Let's get that fixed.

Where's the plasters?

CIARA:

Oh.

(Paddy clears throat)

(both giggling, laughing)

(laughing):

Oh, my God.

Look at their faces.

CIARA: You should have

taken a picture. (laughs)

Of course I'm a bloody doctor.

-Oh! -(laughter)

-We totally had them.

-We totally had them, right?

-Well, yeah, I mean...

(laughing):

You f*cking as*h*le.

Come on. How else

could we afford all this?

Come here.

(laughter)

(chickens clucking)

-PADDY: Here, try that.

-BEN: What is this?

They say it smells like

a rugby club locker room.

LOUISE and BEN:

Mmm!

PADDY:

Yeah, right?

Agnes, love, you have to eat

your vegetables.

PADDY:

...I'm increasingly finding

the simple things in life

bring you joy.

Eat your greens, sweetheart.

And, Agnes, we don't chew

with our mouths open.

PADDY: Gorgonzola,

Camembert, Emmental.

You can keep it.

Stinking Bishop is number one.

-BEN: Never had it.

-Get it. -Agnes?

Please, could you stop

telling my daughter what to do?

BEN:

Mmm!

But she needs to be told, so...

Yes, but you're not her mother.

I'm her mother.

Yeah. But you do agree, right?

That it's disgusting

eating with my mouth open.

(laughs):

Okay.

(laughs): Yeah. But it's for

her parents to tell her.

-Is that the rule?

-Yeah.

Mm. No, Ciara grew up

in the care system.

All the kids

parenting each other,

doing what they were told.

I mean, she doesn't know

"the rules." Sorry.

CIARA: I didn't mean anything

by it, Louise.

PADDY: To be fair, though, you

did cross a line for Louise.

You don't criticize

other people's children.

You should say sorry.

(chuckles):

It's okay.

I'm sorry, Louise.

And to Agnes.

I'm sorry, Agnes.

It's okay.

Louise?

There anything

you'd like to say?

(chuckles softly)

I-I maybe...

overreacted.

Off we go. It's all good.

It's all good.

A healthy disagreement.

Teach our kids we can be honest

with each other.

Right, top up. (clears throat)

Agnes, um, why don't

you and Ant show us your, um,

your dance routine

y'all have been working on?

-(chuckles): Yes.

-Sure.

-Is it all set up, ready to go

in the tape deck? -Yep.

All right.

You tell me when you're ready.

Ready.

("Cotton Eye Joe" by Rednex

playing over speakers)

-(Paddy chuckles) -I'd been

married long time ago

Where did you come from?

Where did you go?

Where did you come from,

Cotton Eye Joe?

If it hadn't been

for Cotton Eye Joe

I'd been married

long time ago

-(Louise whoops)

-Where did you come from?

Where did you go?

Where did you come from,

Cotton Eye Joe?

-(music stops)

-Ant, what's...

What's the matter, mate?

You're...

I mean, he's completely

out of time with the music.

LOUISE: No, no, no.

You guys were doing great.

Just-just-just start it again.

Yeah, no, I'll start it again.

Sorry about that.

-It's okay.

-Ready?

-(music resumes)

-Cotton Eye Joe?

One, two, three.

(Louise chuckles)

If it hadn't been

for Cotton Eye Joe...

PADDY:

f*cking hell.

Where did you come from,

where did...

-(music stops)

-Ant? Ant.

Wha-- (laughs)

What are you doing?

Come on, man. Concentrate.

All right?

Hey, Paddy, they're doing great.

Yeah, but he's got no rhythm

at all, and he's spoiling

-the routine.

-Paddy, they're just kids.

PADDY: Listen,

my dad always used to say

you have to work

really hard at life,

otherwise you will

amount to nothing.

Ant, come on, mate.

Feel the music.

This is the one, yeah?

-(music resumes)

-Where did you go?

Where did you come from,

Cotton Eye Joe?

If it hadn't been

for Cotton Eye Joe

-Whoo! -I'd been married

long time ago

Where did you come from?

Where did you go?

Where did you come from...

PADDY: Oh, my G--

Oh, my God. Oh, my God.

Ant. What is wrong with you?

How hard can it be?

Just feel the rhythm

in your feet.

Like one, two, three, four,

five, six, seven, eight.

Ant, listen to your dad, please.

Come on, look at Agnes.

Do what she's do--

-She's doing it.

-I don't want to dance anymore.

-PADDY: Whoa. What... (scoffs)

-Honey.

No, she's got to do it.

She's got to come back.

-No, she doesn't want to dance

anymore. -Go, go. Go.

Go get your friend, boy.

Come on.

I... (groans)

Mate. Mate.

If it hadn't been

for Cotton Eye Joe...

Honey. One more time.

-Ben. She doesn't want to.

-I hear you. I hear you.

One more time. Mm.

Hey.

(chuckles):

Hey. Here we go.

This is the one, boy.

-(Paddy clears throat)

-(music stops)

Let me rewind it.

(tape rewinding)

Come on.

Come on, come on, come on.

Takes ages.

-Ready?

-(music resumes)

If it hadn't been

for Cotton Eye Joe

I'd been married

long time ago

Where did you come from?

Where did you go?

Where did you come from,

Cotton Eye Joe?

(sighs sharply)

If it hadn't been

for Cotton Eye Joe

I'd been married

long time ago

Where did you come from?

Where did you go?

Where did you come from,

Cotton Eye Joe?

-No!

-Paddy!

-f*ck.

-Agnes, come here.

PADDY: It's all right.

It's all right. It's all right.

It's all right, boy.

It's all right.

You can still do it on your own.

Five, six, seven, eight.

Come on.

-Hey, turn it off. Turn it off!

-What? -(music stops)

-Is there a problem?

-Christ, Paddy, he's a child.

What is wrong with you?

Why are you talking

to him like that?

Ah. Now you're parenting

our child.

Because we do things

differently.

-Wow.

-LOUISE: Oh.

This is not about

doing things differently.

This is about doing

what is right, okay?

I mean, y-you should be

offering your son

some love while he's crying,

not shouting at him.

I mean, come on, Paddy.

He's just a kid.

Just let him dance.

That was not dancing.

Ant, go to your room.

-God, I can't listen to the way

you talk to him. -Paddy...

-Go to your room! -Paddy!

-Stop! Enough! Stop it!

-Listen to me.

-(grunts)

-(Louise sobs)

-Dad.

Sorry.

Let me talk to your mom

for just a second, okay?

Jesus Christ.

I want to pack up the car,

and I want to leave now.

Okay.

Just... Look, Louise.

We've had a little bit

too much to drink to...

No, I don't care. I want to go.

Okay, Louise, we'll go.

-Just... just let me get some

coffee in me first. -(sobbing)

-All right? -We shouldn't

have come back here.

-You...

-Okay.

Jesus, Ben, you have no problem

standing up to me,

but you won't say sh*t to him.

(bubbling softly)

(sighs)

(breathing heavily)

CIARA: Please

don't leave before Paddy's up.

He'll be so angry, and it would

be better for me and for Ant.

Wait, is it that bad?

If you could just

let him save face.

Like a reminder on your phone

of an appointment

you can't miss.

(Paddy groans softly)

God, he's rubbish, isn't he?

(chickens clucking)

Ant, what is it?

(door creaking softly)



(drawers opening and closing)

(Ant panting shakily)



(Ant panting sharply)

That's your...

(Agnes crying softly)

(sighs)



AGNES:

Oh, my God.

Oh, my God. (panting)

(camera clicking)

I need to get my parents alone.

They'll know what to do.

(lock clicks)

Dad. Play catch?

When I finish my coffee.

(Agnes sighs)

(gasps)

Oh, f*ck. (inhales sharply)

All right, shithead.

(sniffs)

What's the matter?

Cat got your tongue?

(sighs):

What the f*ck?

Oh, coffee.

That's a good lad.

Show me.

Show me love.

(sighs)

(Paddy breathing heavily)

You're smelling stale, boy.

Oh, f*ck.

(snorts)

-(laughs)

-(snorts)

(laughs):

Oh, now you want a piggyback.

You cheeky sod.

Actually, it'll show everyone

we're still friends. Come on.

Come on. Hop on.

(grunts) Oh, f*cking hell.

What have you been eating?

Come on. (grunts)



(pants softly)

(panting)

Hey.

I am so sorry.

I-I just...

I drank way too much,

and I was way out of line.

(Louise chuckles softly)

I think we all drank too much.

Where's Agnes?

BEN:

Here she is.

Hey, honey.

LOUISE:

You okay?

Aggie, what's the matter?

-BEN: Did you cut yourself?

-Oh.

Oh. No.

Uh, okay, that's fine. Come on.

-What's going on? -I'm gonna

take you to the bathroom.

-CIARA: She got her period.

-Oh.

-(Agnes crying) -Oh. Oh,

this is all totally normal.

Mom, no, it's not.

Ah! Listen, I need a beer.

Do you want one?

No, I'm good.

Whoa! (laughs) All right.

All right. Where's this

newfound enthusiasm come from?

Five more minutes, all right?

(sighs)

Go on, Ben.

Put some heat in that arm.

(chuckles):

Whoop! f*ck. Wow.

(panting)

(Agnes panting)

We're gonna leave, right?

Aggie, we're gonna leave.

We just need to stay calm.

-How can I stay calm?

-Okay.

What about Ant?

We need to take Ant.

Aggie? Listen.

I need you to be brave, okay?

Can you be brave?

-Yeah.

-Okay.

You're gonna stay here,

and you're gonna sit tight,

and you're gonna lock the door.

Yeah?

-Mom...

-Aggie.

Lock the door.

Okay?

(gasping)

Everything all right?

LOUISE: (clicks tongue)

Yeah, it'll be fine.

She just, uh...

got herself into

a bit of a state.

Ben, she asked for you.

He's always better with her

when she's like this.

Hmm.

-Sorry about this, guys.

-PADDY: No, no, no, no.

No worries.

Hey.

Can we do anything?

No. It'll be fine.

Don't worry.

(exhales sharply)

LOUISE:

(panting) Okay.

Okay.

Louise.

Louise, what are you doing?

CIARA:

Everything okay in there?

Yeah, we're all good.

Anything we can get you?

No, no, no.

We'll just be a minute.

(hushed):

We can't let on.

Yeah?

We can't look stressed

or scared.

We just have to go out there

and be completely normal, okay?

We've been pretending

it's normal since we got here.

This is so not normal.

(whimpers)

I can't do this.

I can't go out there.

(crying softly)

Okay. You're right.

You're right, baby.

It's not normal.

And you don't have to pretend

it's normal.

I think that we tell them

that you had

your first period, yeah?

And-and-and that

you're super freaked out

and that even your daddy

couldn't calm you down,

so we just need to get you home.

Okay?

Oh, no, no, baby, baby.

All those tears are good.

All those anxious thoughts,

you can show them.

-Okay?

-Okay.

Okay.

(breathes deeply)

(sighs):

Okay.

(clears throat)

Yeah, all right. See you soon.

(sighs)

-Hey, how is she?

-Hi. (chuckles)

Oh, she's, uh, well, she's

pretty freaked out. (chuckles)

Oh, bless her.

-Yeah. -It's a big day.

-Yeah.

LOUISE:

Yeah, yeah.

She's just totally overwhelmed

and-and, uh...

I think it might be best

if we got her home.

-Yeah.

-Oh. Okay.

Well, does she want

to lie down or...?

No. I-I-I think she just,

she just wants her own bed,

right, sweetie?

Yeah, I mean, I-I--

She'll probably just sleep

in the car, to be honest.

Aw. It's okay, love.

(gasps softly)

-(chuckles): Oh.

-LOUISE: Oh.

She's just feeling

a little self-conscious.

There's no need.

-Perfectly natural.

-PADDY: Yeah.

Yeah, you're not a girl anymore.

You're a woman now.

Must have been

a bit of a shock for you.

Out there.

-Would you like a drop

of brandy? -BEN: No.

I think

we're gonna hit the road.

Yeah. Yeah, of course.

You know, we-we had

a really great time.

Well... well, I hope so.

I know we can both be...

-A bit much.

-(Paddy and Ciara chuckle)

Oh, God. No, no. Really.

-I mean, you-you guys

have been... -Aw.

Just a breath of fresh air.

(chuckles)

Oh, well, that is

very sweet of you to say.

You're sure I can't quickly

make you some sandwiches

for the journey?

BEN:

Oh, that's so kind of you,

but we'll, uh,

we'll just stop on the way.

(quietly):

Oh, sh*t. The tire.

LOUISE (quietly):

We'll just drive on it.

BEN:

No, they're gonna see it.

We'll be gone.

But they have to open the gate.

All right, well, uh, again,

thanks so much.

-You're all set?

-LOUISE: Yep.

-Yeah. Great.

-LOUISE: Yeah.

PADDY:

Oh, you're kidding.

Oh, no.

Ugh.

That is bad luck. Come see.

Yeah. Yeah, you got a nail.

That is really, really bad luck.

Well, um, you have a phone?

I can call the AA.

Behave. You don't need the AA.

I can plug this in a jiffy.

Come on.

No, it's fine.

W-We got an annual membership.

It's the least I could do, man.

Come on. Come give me a hand

with the kit.

Won't be a tick.

Just around here.

(keys jingle)

(light switch clicks)

(Paddy sighs)

(impact wrench whirring)

Do me a favor.

Grab that jack.

(Paddy sighs)

(impact wrench whirs)

(impact wrench whirs)

PADDY:

Right.

Well, why don't we call it, uh,

90 for labor, 70 for parts.

CIARA (chuckles):

Paddy.

(Paddy and Ciara laugh)

All right, g*ng.

-Let's hit the road.

-Yeah.

Agnes, you, uh,

got everything you need?

BEN:

Yep.

-(knuckles cracking)

-LOUISE: Yeah.

PADDY:

You absolutely sure?

-Mom.

-LOUISE: Mm-hmm?

LOUISE:

Um...

Oh, no.

How the hell

did he get up there?

Ant, you do that?

I just want to be at home.

Well, you can't leave

without Hoppy, right, mate?

No, we can't.

I was actually doing

the guttering

just before you guys arrived.

You know what, mate?

You're taller than I am.

Longer arms and all that.

I'll hold the bottom.

You get up there and grab it.

(sniffs)

-All good?

-BEN: Yeah.



-(ladder rattles)

-(Ben grunts)

Whoop. (chuckles)

Sorry, mate. It slipped.

Don't worry, I've got you.



PADDY: Whoa! Whoa! Whoa!

Careful, mate. Careful.

That's on you. (chuckles)

You all right?

Whoa.

(grunts)

(sighs)

Oh, no.

Oh, I'm so sorry, Agnes.

I think an animal

must have got to him.

You all right?

Mm.

(sighs) It's okay.

We'll get him home

and get him all fixed up.

Well, thank you for coming.

-Oh, say goodbye to Agnes.

-Bye, Ciara.

Come here, big man.

Hug it up. Yeah.

(quietly):

We won't leave you.

You be safe on those roads,

all right?

-Ant?

-Hey, you don't get away.

-Come here.

-(chuckles)

(Paddy grunts)

(softly):

Yeah.

BEN:

All right.

Well, next time

you guys are in London,

just give us a...

LOUISE:

Yeah, yeah, definitely.

Yeah, you guys let us know

when you get there.

You could send me a...

little text.

Absolutely.

Except you won't, will you?

(smacks lips) I'm sorry?

You're still not being

completely honest, are you?

(chuckles)

No, we're not.

We've been lying to you.

I mean, we're not gonna

invite you to London, are we?

We're never gonna

see you again because

Ben and I,

we won't be together.

(chuckles)

I betrayed Ben with someone else

because I was deeply unhappy

in my marriage.

(clicks tongue)

And, uh, I've apologized,

but it has become clear

this weekend

that maybe Ben and I

can't get past this.

Wow.

Honesty.

Finally.

We believe honesty is the

first step to fixing things,

and we think you can.

Ben told me he wants to.

Ben loves you very much, Louise.

(chuckles softly)

I'm sorry. I don't know

why I said all that.

No.

No, it's good to get it

all out. (chuckles)

(sighs) I think we should go.

Yeah, we'll send you

the bill for the therapy.

And we'll see you both

in London. (chuckles)

Yeah.

Ant, could you get

the gate for us?

Ant!

-(button clicks)

-No need, mate.

(gate creaking)

(Ant sighs)

All right.

All right, everybody,

just stay nice and calm.

-What about Ant?

-We're gonna come back for him.

We can't leave him.

Baby, if we don't get away,

we can't help him.

Okay? You understand that?

All right. Just smile and wave.

Bye.



Dad! Dad, stop!

-What?

-He-he threw Ant in the lake!

BEN:

sh*t!

g*dd*mn it!

All right, take the wheel.

-Just drive!

-Ben!

(gasping)

(button clicks)

(Louise gasping)

AGNES:

Mom, stop!



Ant!

(both gasping)

(Ant gasping, coughing)

(g*nsh*t)

(Louise gasping)

PADDY: What do we want here?

We want... pay and transfer?

200 grand. f*cking tasty.

Uh, make transfer,

pay new payee and done.

You're never gonna

get away with this.

Mike's already got a buyer

for your car.

Next week, you're gonna send

an email to your landlord

saying you're moving home.

You'll send another to the

school saying the same thing.

You don't know your neighbors,

got no f*cking job.

Nobody's gonna miss you

in a place like London.

Look, you can have

whatever you want.

Just please don't hurt

my family.

Oh, your perfect f*cking family?

You don't even love 'em, mate.

If you did, you'd have left him

in the pond with his parents.

Don't worry, mate,

you'll be with them soon.

Full amount. Transfer.

(device beeps)

Why are you doing this?

Because you let us.

You f*cking people.

With your gas-free Teslas

and your... line-caught tuna.

Giving yourself a gold star

because you made friends

with a couple

with a disabled kid.

Makes me f*cking sick.

Agnes, love.

Roll that sleeve up, yeah?

It's-it's all right.

It's all right.

It's just veterinary ketamine.

Not gonna k*ll her.

It's better to sedate.

Otherwise, they wriggle around

and make a right bloody mess.

Ant will tell you.

(chuckles)

It's just, except he can't.

Ciara, please.

No, you can't let him do this.

(Paddy laughs)

It was her

who first wanted a kid.

Just never seems to work out,

does it, love?

Maybe this time.

Yeah.

(gasping)

Look, Paddy, please.

Hands behind your back.

(grunting)

(Paddy yells)

(Ciara yelps)

(pained yelling)

CIARA:

Louise.

Louise, please don't leave me

here with him.

-BEN: Ant!

-You've seen how he hurts me.

I'm a victim here, too.

Please, please, please.

I was his first!

I was Agnes's age!

Please, you've got

to believe me!

Please don't leave me here

with him!

f*ck her.

-Come on. Come on.

-Please! Louise, please!

LOUISE:

Come on.

Get in.

(all panting)

(tires squealing)

LOUISE:

Oh!

sh*t. Who is it?

(Louise screaming)

-sh*t! sh*t!

-Oh, my God!

(tires squealing)

In the house!

There's a landline in the house!

(panting)

Bolt the shutters!

(grunting angrily)

-The f*ck! (groans)

-Paddy.

-f*ck off!

-(gasping)

This is your f*cking fault.

You nearly f*cking shot me!

(both grunt)

Baby, I need you with me.

(Paddy breathing heavily)

(Ciara whimpers)

(grunts)

Paddy, mate!

Mate, they're in your house.

They're going nowhere.

Mate, I don't mind

providing services

and taking my share, but this...

-They see your face, Mike?

-Yeah.

Then you are in this,

you like it or not.

Okay. (gasping)

Um, um, uh, telephone,

telephone! Come on.

Thank you.

Um...

Okay.

Oh, no, f*ck!

It's, um, uh, nine-nine-nine.

(line ringing)

Anything?

-Uh-huh. -WOMAN (over phone):

Emergency. Which service?

BEN:

What? What?

(frustrated yell)

It's gone dead.

-Um...

-f*ck.

Okay. (panting)

Ben?

Look.

If we got out there

and then down into the woods,

-I mean, in the dark, they...

-No. L-Louise, they have g*ns.

Okay? They-they hunt at night.

Okay, if they get inside,

they are gonna k*ll us.

Louise, I don't know what to do.

(stammers):

I don't know.

I... I don't know.

I'm so sorry, Louise.

I-I should-- I-- f*ck.

I-I should've listened to you.

-It's okay.

-(stammers) No, it's not okay!

Like, I should have

not let us come.

I-- We shouldn't have stayed.

-(stammering)

-Ben! Stop it!

Listen to me. (panting)

Look at your daughter.

Your family needs you.

AGNES:

Dad, I don't like it.

-LOUISE: Okay.

-BEN: Look, it's okay, honey.

They're just trying

to scare us. All right?

It's okay, guys.

("Eternal Flame" by The Bangles

playing faintly in distance)

Or is this burning

(playing over car speakers):

An eternal flame?

Never forget this, Ben!

(breathing heavily)

PADDY (singing along): Do you

feel my heart beating?

Do you understand?

(shouting):

Do you feel the same?

Am I only dreaming?

Is this burning

An eternal flame?

Louise. Louise.

Look, the thatched roof

above the barn.

If we could light that on fire,

then someone might see it.

LOUISE:

Oh, my gosh.

-Is it gonna work?

-Oh, God, I don't know.

It's 150 proof, but...

(stammers)

I don't know.

-All right.

-Okay. Okay.

Oh, God. Fast. Go.

Ben, go! Jesus!

BEN:

Okay.

(g*nsh*t)

(Louise screams)

-Jesus! Oh! Oh, my gosh!

-Oh, sh*t! Louise!

-Oh, no, Ben! Pick it up!

-Throw it! Oh!

BEN: All right, sh**t the g*n,

and I'll throw it.

-It's our last shot.

-Just sh**t the g*n, okay?

Okay!

Oh, f*ck!

Okay, go. Go, go.

(Louise panting)

(both grunting)

Did you get it?

Yeah, honey. Help's on the way.

Okay. Come on.

Let's go. Come on.

-(Paddy growls)

-f*ck!

(laughs)

Mate, your f*cking car's

on fire. Let's finish it, eh?

We've got them

on the hook, Mike.

I told you, you should

just top them first thing.

Why do you do this,

play with your food?

You're like my mum's cat.

You go and you get

on that roof, yeah?

(breathing heavily)

Okay, you guys sit tight.

You, too, Hoppy.

Now, you don't move

and you don't make a sound

until you hear

my voice again, okay?

Okay.

(drawer closes)

(breath trembling)

PADDY:

Ben, mate?

That you in there?

You gonna give me

a little dance, Ben?

You gonna step up or are you

gonna let us sh*t all over you

like that fellow

on your wife's phone?

Ben?

If it was just

you and him, right,

you've got a g*n

against his head,

what would you do?

(dog barking in distance)

(laughing)

Oh, you've blown up my car,

you cheeky c**t.

What was that?

You're gonna have to pay

for that, Ben.

Coming in, Ben!



(panting)

(clatter on roof)

(footsteps creaking)

It's the roof.

Ben.

Honey.

(clatter on roof)

-(door creaking)

-(straining)

(grunts)

(grunts softly)

Ant!

(breath trembling)

Where are you, boy?

I know you can hear me!

LOUISE:

Oh, you f*ck.



(panting)

(panting softly)

Not gonna pretend I'm not angry.

(pained grunt)

f*ck! (pained grunt)

(grunts fiercely)

(grunting)

(straining)

Ah, ya f*ck. (yelling)

(yelling)

(pained screaming)

(shrieks)

(groaning)

-(panting)

-(g*n racks)

(Paddy grunts, yells)

(grunting forcefully)

(growls)

(pained yell)

-(knocking)

-Paddy!

(panting, groaning)

Where is she?

Through there.

Check the cupboard.

-Okay.

-(grunts)

(door opens)

Ant, love? (panting)

If you make some noise

and show us where you are,

we'll go easy on you.

No reason we can't

keep you both.

PADDY:

Don't...

and I'm gonna put you feet first

through the f*cking

wood chipper!

(whispers):

Let's go up.

(Ant grunting softly)

(muffled coughing)

(quiet breathing)



(panting)

(deep breathing

over phone speaker)

-(screaming)

-You f*cking...

-(Paddy screaming)

-Go! Go, go, go!

(Louise yells)

Go! Go! Go!

Oh, sh*t!

Go, go. Right there.

PADDY:

Water.

-Oh, f*ck. Water!

-(gasping)

Come on, kids. Go in.

Go in. That way, that way!

(Louise and Agnes scream)

(grunting)

(straining)

-(Mike hissing)

-(Ben yells)

-(Louise gasps)

-(Ben yelling)

(Louise screams)

(Louise gasping)

Holy sh*t.

(gasping)

(Paddy screaming in distance)

(breathlessly):

Just grab his keys.

-What? What?

-His car keys.

Through the loft. The loft.

Come on.

(pained screaming)

-Can you see?

-(coughing)

I can see.

Look, look.

You... you have to do this.

You have to go now.

You got to get after them,

all right?

This is your f*ck, love.

You go fix it or it's over.

Give me it.

(pained screaming)

Upstairs.

Oh.

BEN:

Okay. Oh, thank God.

-Okay. Okay.

-Oh.

-Dad!

-(grunts)

LOUISE:

Are you okay?

-Yeah. Yeah.

-Okay. Okay.

Come on.

There you go.

(panting)



-All right. All right.

-No.

All right, just be careful.

-Okay.

-LOUISE: Okay.

Get on the ladder.



-(gasps)

-(grunts)

(screaming)

Ciara? (pants)

Ciara!

-Dad! Help me!

-BEN: Aggie!

-Dad, please!

-I got you!

-(Ben straining)

-(Agnes gasping)

(panting sharply)

I got you. I got you.

(straining)

(panting)

Oh, God. Are you okay?

(panting)

-(pained grunt)

-(muffled gasping)

(groaning)

Oh, my God.

(pained grunting)



All right.

Go hide behind the car.

Hey, go through the yard.

Hey.

(panting)

Go. Go.

Take Ant back to the car.

I'll be right behind you.

LOUISE:

We go together.

(pained grunting)

(panting)

-(sighs)

-Oh, God.

Ciara?

-Hey! Hey!

-(shrieks, gasps)

You throw that g*n, Ben.

LOUISE:

No.

Oh, baby.

Ciara, my darling?

(crying):

Ciara. Oh, my darling.

Oh, please. Please.

Do whatever you want to us.

But please... (panting)

This peach?

You think I'm gonna hurt her?

(Agnes breathing shakily)

You took my Ciara away from me.

She's all I've got

to take care of me now.

(whimpers)

But I promise you both...

...we'll look after each other.

-No!

-f*ck!

(all gasping)

(Paddy groaning)

Oh, God!

(growls)

(pants sharply)

(groaning)

(Louise panting)

Okay.

(growling)



(grunts softly)

Ant, come on.

Ant.

Come on.

That's my boy.

(grunting)

(yelling wildly)

(shrieking)

(yelling wildly)

(panting)









("Eternal Flame"

by The Bangles playing)

Close your eyes

Give me your hand, darling

Do you feel

my heart beating?

Do you understand?

Do you feel the same?

Am I only dreaming?

Is this burning

An eternal flame?

I believe

It's meant to be, darling

I watch you

when you are sleeping

You belong with me

Do you feel the same?

Am I only dreaming?

-Or is this burning

-Burning

An eternal flame?

Say my name

Sun shines through the rain

A whole life so lonely

And then come

and ease the pain

I don't want to lose

this feeling

Oh



Say my name

Sun shines through the rain

A whole life so lonely

And then come

and ease the pain

I don't want to lose

this feeling

Oh

Close your eyes

Give me your hand

Do you feel

my heart beating?

Do you understand?

Do you feel the same?

Am I only dreaming?

Or is this burning

An eternal flame?

Close your eyes

Give me your hand, darling

Do you feel

my heart beating?

Do you understand?

Do you feel the same?

Am I only dreaming?

Is this burning

An eternal flame?

Close your eyes

Give me your hand, darling

Do you feel

my heart beating?

Do you understand?

Do you feel the same?

Am I only dreaming?

Oh

An eternal flame

Close your eyes

Give me your hand, darling

Do you feel

my heart beating?

Do you understand?

Do you feel the same?

-Am I only dreaming?

-(song fades)



(music ends)